@@ -2,7 +2,7 @@
 
 # enpt_enmapboxapp, A QGIS EnMAPBox plugin providing a GUI for the EnMAP processing tools (EnPT)
 #
-# Copyright (C) 2018-2022 Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
+# Copyright (C) 2018-2023 Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
 #
 # This software was developed within the context of the EnMAP project supported
 # by the DLR Space Administration with funds of the German Federal Ministry of
@@ -20,7 +20,7 @@
 # details.
 #
 # You should have received a copy of the GNU Lesser General Public License along
-# with this program.  If not, see <http://www.gnu.org/licenses/>.
+# with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 """This module provides the base class for EnPTAlgorithm and ExternalEnPTAlgorithm."""
 
@@ -66,6 +66,7 @@ class _EnPTBaseAlgorithm(QgsProcessingAlgorithm):
     P_drop_bad_bands = 'drop_bad_bands'
     P_disable_progress_bars = 'disable_progress_bars'
     P_output_format = 'output_format'
+    P_output_interleave = 'output_interleave'
     P_path_earthSunDist = 'path_earthSunDist'
     P_path_solar_irr = 'path_solar_irr'
     P_scale_factor_toa_ref = 'scale_factor_toa_ref'
@@ -239,12 +240,18 @@ class _EnPTBaseAlgorithm(QgsProcessingAlgorithm):
         self.addParameter(
             QgsProcessingParameterEnum(
                 name=self.P_output_format,
-                description="Output format (file format of all raster output files).",
+                description="Output format (file format of all raster output files)",
                 options=['GTiff', 'ENVI'],
                 defaultValue=0),
             advanced=True)
 
-        # output_interleave?
+        self.addParameter(
+            QgsProcessingParameterEnum(
+                name=self.P_output_interleave,
+                description="Output raster data interleaving type",
+                options=['band (BSQ)', 'line (BIL)', 'pixel (BIP)'],
+                defaultValue=2),
+            advanced=True)
 
         self.addParameter(
             QgsProcessingParameterFile(
@@ -457,6 +464,7 @@ class _EnPTBaseAlgorithm(QgsProcessingAlgorithm):
         # replace Enum parameters with corresponding strings (not needed in case of unittest)
         for n, opts in [
             ('output_format', {0: 'GTiff', 1: 'ENVI'}),
+            ('output_interleave', {0: 'band', 1: 'line', 2: 'pixel'}),
             ('mode_ac', {0: 'land', 1: 'water', 2: 'combined'}),
             ('deadpix_P_algorithm', {0: 'spectral', 1: 'spatial'}),
             ('deadpix_P_interp_spectral', {0: 'linear', 1: 'bilinear', 2: 'cubic', 3: 'spline'}),
